pub struct Args {Show 17 fields
pub syscall_number: bool,
pub attach: Option<pid_t>,
pub no_abbrev: bool,
pub string_limit: Option<usize>,
pub file: Option<PathBuf>,
pub summary_only: bool,
pub summary: bool,
pub successful_only: bool,
pub failed_only: bool,
pub env: Vec<String>,
pub username: Option<String>,
pub follow_forks: bool,
pub syscall_times: bool,
pub expr: Vec<String>,
pub json: bool,
pub collapse_exec_retries: bool,
pub command: Option<ArgCommand>,
}Fields
syscall_number: boolDisplay system call numbers
attach: Option<pid_t>Attach to a running process
no_abbrev: boolPrint un-abbreviated versions of strings
string_limit: Option<usize>Maximum string argument size to print
file: Option<PathBuf>Name of the file to print output to
summary_only: boolReport a summary instead of the regular output
summary: boolReport a summary in addition to the regular output
successful_only: boolPrint only syscalls that returned without an error code
failed_only: boolPrint only syscalls that returned with an error code
env: Vec<String>–env var=val adds an environment variable. –env var removes an environment variable.
username: Option<String>Run the command with uid, gid and supplementary groups of username.
follow_forks: boolTrace child processes as they are created by currently traced processes.
syscall_times: boolShow the time spent in system calls in ms.
expr: Vec<String>A qualifying expression which modifies which events to trace or how to trace them.
json: boolDisplay output in JSON format
collapse_exec_retries: boolCollapse repeated failing execve attempts and only show final success
command: Option<ArgCommand>Implementations